@@ -408,8 +408,18 @@ bool CallRouter::isRunning(){
 //DBus Method used by external applications to call via VICaR
 QString CallRouter::callInternationalNumber(const QString& strDestinationNumber){
 
+    QString strErrorMessage;
+
     qDebug() << "Vicar-Daemon: New call requested by external application. Destination number is " << strDestinationNumber;
-    QString strErrorMessage = this->callViaCallingCard(strDestinationNumber);
+
+    if (isValidPhoneNumber(strDestinationNumber)){
+
+        strErrorMessage = this->callViaCallingCard(strDestinationNumber);
+    }
+    else{
+        strErrorMessage = QString("Vicar-Daemon: %1 is not a valid number").arg(strDestinationNumber);
+    }
+
     qDebug() << strErrorMessage;
 
     if (strErrorMessage.isEmpty()){
@@ -419,3 +429,23 @@ QString CallRouter::callInternationalNumber(const QString& strDestinationNumber)
         return strErrorMessage;
     }
  }
+
+//Check whether a string is valid phone number
+bool CallRouter::isValidPhoneNumber(QString strPhoneNumber){
+
+
+/* Remove all dialble characters. The resulting string should be a valid number */    
+    QRegExp regexp = QRegExp("[p+*#]");
+
+    strPhoneNumber = strPhoneNumber.replace(regexp,"");
+
+    qDebug() << "Vicar Daemon: Cleaned up phone number is " << strPhoneNumber;
+
+/* Now remove all digits, the resulting string should be empty, then it is a valid number */
+    regexp = QRegExp("[0-9]");
+
+    strPhoneNumber = strPhoneNumber.replace(regexp,"");
+
+    bool isNumber = strPhoneNumber.isEmpty();
+    return isNumber;
+}
