@@ -101,11 +101,11 @@ int main(int argc, char ** argv)
 
         // register CM on D-BUS:
         if (connection.registerService(cm_service_name)){
-            qDebug(qPrintable(QObject::tr("Service %1 registered with session bus.").
+            qDebug(qPrintable(QObject::tr("Vicar-Telepathy: Service %1 registered with session bus.").
                        arg(cm_service_name)));
         }
         else{
-            qDebug(qPrintable(QObject::tr("Unable to register service %1 with session bus.").
+            qDebug(qPrintable(QObject::tr("Vicar-Telepathy: Unable to register service %1 with session bus.").
                        arg(cm_service_name)));
         }
 
@@ -113,11 +113,11 @@ int main(int argc, char ** argv)
 
     ConnectionManager connection_mgr(&app);
     if (!connection.registerObject(cm_object_path,&connection_mgr)){
-        qDebug(qPrintable(QObject::tr("Unable to register VICaR connection manager at path %1 with session bus.").
+        qDebug(qPrintable(QObject::tr("Vicar-Telepathy: Unable to register VICaR connection manager at path %1 with session bus.").
                    arg(cm_object_path)));
     }
 
-    qDebug(qPrintable(QObject::tr("Enternig main loop.")));    
+    qDebug(qPrintable(QObject::tr("Vicar-Telepathy: Enternig main loop.")));
 //    logfile.close();
     return app.exec();
 }
